<?php
/*
* $Id: cm_header_wholesale.php
* $Loc: /includes/modules/content/header/
*
* Name: WholesaleLite
* Version: 4.7.9
* Release Date: 10/19/2024
* Author: Rainer Schmied
* 	 phoenixcartaddonsaddons.com / raiwa@phoenixcartaddons.com
*
* License: Released under the GNU General Public License
*
* Comments: Author: [Rainer Schmied @raiwa]
* Author URI: [www.phoenixcartaddons.com]
* 
* CE Phoenix, E-Commerce made Easy
* https://phoenixcart.org
* 
* Copyright (c) 2021 Phoenix Cart
* 
* 
*/

  class cm_header_wholesale extends abstract_executable_module {

    const CONFIG_KEY_BASE = 'MODULE_CONTENT_HEADER_WHOLESALE_';

    public function __construct() {
      parent::__construct(__FILE__);
    }

    public function execute() {
      global $Linker;

      if (!Text::is_empty(MODULE_CONTENT_HEADER_WHOLESALE_CONTENT_PAGES)) {
        $pages_array = [];

        foreach (explode(';', MODULE_CONTENT_HEADER_WHOLESALE_CONTENT_PAGES) as $page) {
          $page = trim($page);

          if (!empty($page)) {
            $pages_array[] = $page;
          }
        }

        if (in_array(Request::get_page(), $pages_array)) {

        	$content_width = (int)MODULE_CONTENT_HEADER_WHOLESALE_CONTENT_WIDTH;

        	if ( isset($_SESSION['customer_id']) && isset($_SESSION['wholesale_group']) && $_SESSION['wholesale_group'] > 0 ) {
        		$output = MODULE_CONTENT_HEADER_WHOLESALE_WSCUSTOMER_TEXT;
          } else if ( isset($_SESSION['customer_id']) && !isset($_SESSION['customer_is_guest']) ) { //PWA guest checkout support do not show module to guests
        		$output = sprintf(MODULE_CONTENT_HEADER_WHOLESALE_RTCUSTOMER_TEXT, $Linker->build('contact_us.php'), $Linker->build('conditions.php'));
        	} else {
        		$output = MODULE_CONTENT_HEADER_WHOLESALE_GUEST_TEXT;
        	}
        	if ( $output != '' ) {

            $tpl_data = [ 'group' => $this->group, 'file' => __FILE__ ];
            include 'includes/modules/content/cm_template.php';
        	}
        }
      }
    }

    protected function get_parameters() {
      return [
        $this->config_key_base . 'STATUS' => [
          'title' => 'Enable Header Wholesale Message Module',
          'value' => 'True',
          'desc' => 'Do you want to enable the Wholesale Message content module?',
          'set_func' => "Config::select_one(['True', 'False'], ",
        ],
        $this->config_key_base . 'CONTENT_WIDTH' => [
          'title' => 'Content Container',
          'value' => 'col-sm-12',
          'desc' => 'What container should the content be shown in? (col-*-12 = full width, col-*-6 = half width).',
        ],
        $this->config_key_base . 'CONTENT_PAGES' => [
          'title' => 'Pages',
          'value' => implode(';', $this->get_default_pages()),
          'desc' => 'The pages to add the Wholesale Message to.',
          'use_func' => 'page_selection::_show_pages',
          'set_func' => 'page_selection::_edit_pages(',
        ],
        $this->config_key_base . 'SORT_ORDER' => [
          'title' => 'Sort Order',
          'value' => '0',
          'desc' => 'Sort order of display. Lowest is displayed first.',
        ],
      ];
    }

    public static function get_default_pages() {

    	$exclude_array = ['checkout_process.php',
                   			'download.php',
                   			'redirect.php',
                   			'ssl_check.php'];
    	$file_extension = substr(Request::get_page(), strrpos(Request::get_page(), '.'));
    	$files_array = [];
    	if ($dir = @dir(DIR_FS_CATALOG)) {
    		while ($file = $dir->read()) {
    			if ( !is_dir(DIR_FS_CATALOG . $file) && !in_array($file, $exclude_array) ) {
    				if (substr($file, strrpos($file, '.')) == $file_extension) {
    					$files_array[] = $file;
    				}
    			}
    		}
    		sort($files_array);
    		$dir->close();
    		return $files_array;
    	}
    }

  }
