<?php
/*
* $Id: cd_wholesale.php
* $Loc: /includes/modules/customer_data/
*
* Name: WholesaleLite
* Version: 4.7.9
* Release Date: 10/19/2024
* Author: Rainer Schmied
* 	 phoenixcartaddonsaddons.com / raiwa@phoenixcartaddons.com
*
* License: Released under the GNU General Public License
*
* Comments: Author: [Rainer Schmied @raiwa]
* Author URI: [www.phoenixcartaddons.com]
* 
* CE Phoenix, E-Commerce made Easy
* https://phoenixcart.org
* 
* Copyright (c) 2021 Phoenix Cart
* 
* 
*/

  class cd_wholesale extends abstract_customer_data_module {

    const CONFIG_KEY_BASE = 'MODULE_CUSTOMER_DATA_WHOLESALE_';

    const PROVIDES = [ 'wholesale' ];
    const REQUIRES = [  ];

    protected function get_parameters() {
      return [
        static::CONFIG_KEY_BASE . 'STATUS' => [
          'title' => 'Enable Wholesale Module',
          'value' => 'True',
          'desc' => 'Do you want to add the module to your shop?',
          'set_func' => "Config::select_one(['True', 'False'], ",
        ],
        static::CONFIG_KEY_BASE . 'GROUP' => [
          'title' => 'Customer data group',
          'value' => '4',
          'desc' => 'In what group should this appear?',
          'use_func' => 'customer_data_group::fetch_name',
          'set_func' => 'Config::select_customer_data_group(',
        ],
        static::CONFIG_KEY_BASE . 'PAGES' => [
          'title' => 'Pages',
          'value' => 'customers',
          'desc' => 'Only used on Admin Customers page',
          'set_func' => 'cd_wholesale::readonly(',
        ],
        static::CONFIG_KEY_BASE . 'SORT_ORDER' => [
          'title' => 'Sort Order',
          'value' => '3600',
          'desc' => 'Sort order of display. Lowest is displayed first.',
        ],
        static::CONFIG_KEY_BASE . 'TEMPLATE' => [
          'title' => 'Template',
          'value' => 'includes/modules/customer_data/cd_whole_row_input.php',
          'desc' => 'What template should be used to surround this input?',
        ],
      ];
    }

    public function get($field, &$customer_details) {
      switch ($field) {
        case 'wholesale':
          if (!isset($customer_details[$field])) {
            $customer_details[$field] = $customer_details['wholesale']
              ?? $customer_details['customers_wholesale'] ?? null;
          }
          return $customer_details[$field];
      }
    }

    public function display_input(&$customer_details = null) {
      
      $label_text = MODULE_CUSTOMER_DATA_WHOLESALE_ENTRY_GROUP;

      $wholesale_array = [
                          ['id' => '0', 'text' => MODULE_CUSTOMER_DATA_WHOLESALE_ENTRY_RETAIL],
                          ['id' => '1', 'text' => constant('MODULE_STORE_WHOLESALE_ENTRY_WHOLESALE_' . strtoupper($_SESSION['language']))]
                         ];

      $wholesale = null;
      if (isset($customer_details) && is_array($customer_details)) {
        $wholesale = $this->get('wholesale', $customer_details);
      }
        
      $input_id = 'wholesale';
      $input = new Select('wholesale', $wholesale_array);
      $input->set_selection($wholesale);

      include Guarantor::ensure_global('Template')->map($this->base_constant('TEMPLATE'));
    }

    public function process(&$customer_details) {
      $customer_details['wholesale'] = Text::input($_POST['wholesale']);

      return true;
    }

    public function build_db_values(&$db_tables, $customer_details, $table = 'both') {
      Guarantor::guarantee_subarray($db_tables, 'customers');
      $db_tables['customers']['customers_wholesale'] = $customer_details['wholesale'];
    }

    public function build_db_aliases(&$db_tables, $table = 'both') {
      Guarantor::guarantee_subarray($db_tables, 'customers');
      $db_tables['customers']['customers_wholesale'] = 'wholesale';
    }

    public static function readonly($value) {
      return $value;
    }
    
  }
