<?php
/*
* $Id: st_wholesale.php
* $Loc: /includes/modules/store/
*
* Name: WholesaleLite
* Version: 4.7.9
* Release Date: 10/19/2024
* Author: Rainer Schmied
* 	 phoenixcartaddonsaddons.com / raiwa@phoenixcartaddons.com
*
* License: Released under the GNU General Public License
*
* Comments: Author: [Rainer Schmied @raiwa]
* Author URI: [www.phoenixcartaddons.com]
* 
* CE Phoenix, E-Commerce made Easy
* https://phoenixcart.org
* 
* Copyright (c) 2021 Phoenix Cart
* 
* 
*/

  class st_wholesale extends abstract_executable_module {

    public $parameters;

    const CONFIG_KEY_BASE = 'MODULE_STORE_WHOLESALE_';

    public function __construct() {
      parent::__construct(__FILE__);

      $this->description .= '<p>by @raiwa <u><a target="_blank" href="http://www.oscaddons.com">www.oscaddons.com</a></u></p>';
      if (!file_exists(DIR_FS_CATALOG . 'templates/' . TEMPLATE_SELECTION . '/includes/hooks/shop/siteWide/wholesale.php')) {
        $this->enabled = false;
        $this->description = '<div class="alert alert-danger" role="alert">' .
                                 MODULE_STORE_WHOLESALE_HOOK_WARNING .
                             '</div>' .
                             $this->description;
      }

    }

    function execute() {

    }

    function install($parameter_key = null) {
      global $db;

      parent::install($parameter_key);
      
      //install database columns
      if (mysqli_num_rows($db->query("SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_SCHEMA='". DB_DATABASE . "' AND TABLE_NAME='customers' AND COLUMN_NAME LIKE 'customers_wholesale'")) != 1 ) {
      $db->query("ALTER TABLE `customers` ADD COLUMN `customers_wholesale` CHAR(1) CHARACTER SET utf8 COLLATE utf8_unicode_ci NULL DEFAULT NULL");
      }
      // install products_ws_price columns
      if (mysqli_num_rows($db->query("SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_SCHEMA='". DB_DATABASE . "' AND TABLE_NAME='products' AND COLUMN_NAME LIKE 'products_ws_price'")) != 1 ) {
        $db->query("ALTER TABLE products ADD COLUMN `products_ws_price` DECIMAL(15,4) NOT NULL AFTER products_price");
      }
      // install options_values_ws_price columns
      if (mysqli_num_rows($db->query("SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_SCHEMA='". DB_DATABASE . "' AND TABLE_NAME='products_attributes' AND COLUMN_NAME LIKE 'options_values_ws_price'")) != 1 ) {
        $db->query("ALTER TABLE products_attributes ADD COLUMN `options_values_ws_price` DECIMAL(15,4) NOT NULL AFTER options_values_price");
      }

    }

    protected function get_parameters() {

      $config_parameters = [
        'MODULE_STORE_WHOLESALE_VERSION_INSTALLED' => [
          'title' => 'Current Version',
          'value' => '4.7.1. Lite',
          'desc' => 'Version info. It is read only',
          'set_func' => 'st_wholesale::readonly(',
        ],
        'MODULE_STORE_WHOLESALE_STATUS' => [
          'title' => 'Enable Wholesale Module',
          'value' => 'True',
          'desc' => 'Do you want to add Wholesale Prices to your shop?',
          'set_func' => "Config::select_one(['True', 'False'], ",
        ],
        'MODULE_STORE_WHOLESALE_REMOVE_DATA' => [
          'title' => 'Uninstall Removes Database entries',
          'value' => 'False',
          'desc' => 'Do you want to remove the wholesale database entries when uninstall the module? (wholesale customers,  wholesale product prices and wholesale attribute prices will be lost)',
          'set_func' => "Config::select_one(['True', 'False'], ",
        ],
        'MODULE_STORE_WHOLESALE_GLOBAL_DISCOUNT' => [
            'title' => 'Global Wholesale Discount',
            'value' => '10',
            'desc' => 'Global Wholesale percentage Discount for all products with individual Wholesale Price zero. Disabled with zero amount.',
        ],
        'MODULE_STORE_WHOLESALE_TAX_EXEMPT' => [
          'title' => 'Tax Exempt Wholesalers',
          'value' => 'True',
          'desc' => 'Do you want to exempt wholesales from taxes?',
          'set_func' => "Config::select_one(['True', 'False'], ",
        ],
        'MODULE_STORE_WHOLESALE_SPECIAL_PRICE' => [
          'title' => 'Use Special Price',
          'value' => 'True',
          'desc' => 'Do you want to use special price if less than wholesale price?',
          'set_func' => "Config::select_one(['True', 'False'], ",
        ],
        'MODULE_STORE_WHOLESALE_SPECIAL_PRICE' => [
          'title' => 'Use Special Price',
          'value' => 'True',
          'desc' => 'Do you want to use special price if less than wholesale price?',
          'set_func' => "Config::select_one(['True', 'False'], ",
        ],
        'MODULE_STORE_WHOLESALE_WHOLESALER_SHIPPING_MODULES' => [
            'title' => 'Wholesaler Exclude Shipping Modules',
            'value' => '',
            'desc' => 'The shipping modules to exclude for wholesalers',
            'use_func' => 'st_wholesale::show_modules',
            'set_func' => 'st_wholesale::edit_modules(',
        ],
        'MODULE_STORE_WHOLESALE_WHOLESALER_PAYMENT_MODULES' => [
            'title' => 'Wholesaler Exclude Payment Modules',
            'value' => '',
            'desc' => 'The payment modules to exclude for wholesalers',
            'use_func' => 'st_wholesale::show_modules',
            'set_func' => 'st_wholesale::edit_modules(',
        ],
        'MODULE_STORE_WHOLESALE_RETAILER_SHIPPING_MODULES' => [
          'title' => 'Retailer Exclude Shipping Modules',
          'value' => '',
          'desc' => 'The shipping modules to exclude for retailers.',
          'use_func' => 'st_wholesale::show_modules',
          'set_func' => 'st_wholesale::edit_modules(',
        ],
        'MODULE_STORE_WHOLESALE_RETAILER_PAYMENT_MODULES' => [
          'title' => 'Retailer Exclude Payment Modules',
          'value' => '',
          'desc' => 'The payment modules to exclude for retailers.',
          'use_func' => 'st_wholesale::show_modules',
          'set_func' => 'st_wholesale::edit_modules(',
        ],
        'MODULE_STORE_WHOLESALE_SORT_ORDER' => [
          'title' => 'Sort Order',
          'value' => '0',
          'desc' => 'Sort order of display. Lowest is displayed first.',
        ],
      ];

      $lng = new language;
      foreach($lng->catalog_languages as $id => $value) {
      	$key = strtoupper($value['directory']);
        switch ($key) {
        	case 'ESPANOL':
            $config_parameters['MODULE_STORE_WHOLESALE_PRICE_NET_' . $key] = [
                'title' => 'Precio al Mayor (Net) ' . $key,
                'value' => 'Precio al Mayor (Net):',
                'desc' => 'Definición de idioma usado en categories.php',
            ];
            $config_parameters['MODULE_STORE_WHOLESALE_PRICE_GROSS_'. $key] = [
                'title' => 'Precio al Mayor (Gross) ' . $key,
                'value' => 'Precio al Mayor (Gross):',
                'desc' => 'Definición de idioma usado en categories.php',
            ];
            $config_parameters['MODULE_STORE_WHOLESALE_ENTRY_WHOLESALE_' . $key] = [
                'title' => 'Mayorista Product Info' . $key,
                'value' => 'Mayorista',
                'desc' => 'Definición de idioma usado en customers.php',
            ];
            $config_parameters['MODULE_STORE_WHOLESALE_PI_RETAIL_PRICE_' . $key] = [
                'title' => 'Precio Minorista Product Info' . $key,
                'value' => 'Precio Minorista',
                'desc' => 'Definición de idioma usado en el módulo precio product info',
            ];
            $config_parameters['MODULE_STORE_WHOLESALE_PI_WHOLESALE_PRICE_' . $key] = [
                'title' => 'Precio Mayorista Product Info' . $key,
                'value' => 'Precio Mayorista',
                'desc' => 'Definición de idioma usado en el módulo precio product info',
            ];
            $config_parameters['MODULE_STORE_WHOLESALE_OPT_PRICE_1_' . $key] = [
                'title' => 'Precio al Mayor ' . $key,
                'value' => 'Mayorista',
                'desc' => 'Definición de idioma usado en products_attributes.php y módulos product info',
            ];
            $config_parameters['MODULE_STORE_WHOLESALE_OPT_PRICE_SHORT_' . $key] = [
                'title' => 'Precio al Mayor corto ' . $key,
                'value' => 'PM',
                'desc' => 'Definición de idioma usado como Prefijo del Precio al Mayor en la tienda',
            ];
       		break;
        	case 'GERMAN':
            $config_parameters['MODULE_STORE_WHOLESALE_PRICE_NET_' . $key] = [
                'title' => 'Grosshändlerpreis (Netto) '. $key,
                'value' => 'Grosshändlerpreis (Netto):',
                'desc' => 'Sprachdefinition für categories.php',
            ];
            $config_parameters['MODULE_STORE_WHOLESALE_PRICE_GROSS_' . $key] = [
                'title' => 'Grosshändlerpreis (Brutto) ' . $key,
                'value' => 'Grosshändlerpreis (Brutto):',
                'desc' => 'Sprachdefinition für categories.php',
            ];
            $config_parameters['MODULE_STORE_WHOLESALE_ENTRY_WHOLESALE_' . $key] = [
                'title' => 'Grosshändler ' . $key,
                'value' => 'Grosshändler',
                'desc' => 'Sprachdefinition für customers.php',
            ];
            $config_parameters['MODULE_STORE_WHOLESALE_PI_RETAIL_PRICE_' . $key] = [
                'title' => 'Einzelhändlerpreis Produktseite ' . $key,
                'title' => 'Einzelhändlerpreis Produktseite ' . $key,
                'value' => 'Einzelhändlerpreis',
                'desc' => 'Sprachdefinition für Einzelhändler im Preismodul auf der Producktseite',
            ];
            $config_parameters['MODULE_STORE_WHOLESALE_PI_WHOLESALE_PRICE_' . $key] = [
                'title' => 'Grosshändlerpreis Produktseite' . $key,
                'value' => 'Grosshändlerpreis',
                'desc' => 'Sprachdefinition für Grosshändlerpreis im Preismodul auf der Producktseite',
            ];
            $config_parameters['MODULE_STORE_WHOLESALE_OPT_PRICE_1_' . $key] = [
                'title' => 'Grosshändlerpreis ' . $key,
                'value' => 'Grosshändlerpreis',
                'desc' => 'Sprachdefinition für products_attributes.php und product info Modules',
            ];
            $config_parameters['MODULE_STORE_WHOLESALE_OPT_PRICE_SHORT_' . $key] = [
                'title' => 'Grosshändlerpreis kurz ' . $key,
                'value' => 'GHP',
                'desc' => 'Sprachdefinition für Abkürzung Grosshändlerpreis vor Preisen im Onlinestore',
            ];
            break;
        	default:
            $config_parameters['MODULE_STORE_WHOLESALE_PRICE_NET_' . $key] = [
                'title' => 'Wholesale Price (Net) ' . $key,
                'value' => 'Wholesale Price (Net):',
                'desc' => 'Language definition used in categories.php',
            ];
            $config_parameters['MODULE_STORE_WHOLESALE_PRICE_GROSS_' . $key] = [
                'title' => 'Wholesale Price (Gross) ' . $key,
                'value' => 'Wholesale Price (Gross):',
                'desc' => 'Language definition used in categories.php',
            ];
            $config_parameters['MODULE_STORE_WHOLESALE_ENTRY_WHOLESALE_' . $key] = [
                'title' => 'Wholesaler ' . $key,
                'value' => 'Wholesaler',
                'desc' => 'Language definition used in customers.php',
            ];
            $config_parameters['MODULE_STORE_WHOLESALE_PI_RETAIL_PRICE_' . $key] = [
                'title' => 'Retail Price Product info ' . $key,
                'value' => 'Retail Price',
                'desc' => 'Language definition used in the Price Module on the Product Info page',
            ];
            $config_parameters['MODULE_STORE_WHOLESALE_PI_WHOLESALE_PRICE_' . $key] = [
                'title' => 'Wholesale Price Product info ' . $key,
                'value' => 'Wholesale Price',
                'desc' => 'Language definition used in the Price Module on the Product Info page',
            ];
            $config_parameters['MODULE_STORE_WHOLESALE_OPT_PRICE_1_' . $key] = [
                'title' => 'Wholesale Price ' . $key,
                'value' => 'Wholesale Price',
                'desc' => 'Language definition used in products_attributes.php and product info Modules',
            ];
            $config_parameters['MODULE_STORE_WHOLESALE_OPT_PRICE_SHORT_' . $key] = [
                'title' => 'Wholesale Price Short ' . $key,
                'value' => 'WP',
                'desc' => 'Language definition used for Whlolesale Price Prefix in Store',
            ];
        }
      }

      return $config_parameters;
    }

    public function remove() {
      global $db;
      parent::remove();

      if ( defined('MODULE_STORE_WHOLESALE_REMOVE_DATA') && MODULE_STORE_WHOLESALE_REMOVE_DATA == 'True' ) {
      	$db->query("alter table customers drop `customers_wholesale`");
        $db->query("alter table products drop `products_ws_price`");
        $db->query("alter table products_attributes drop `options_values_ws_price`");
      }
    }

    public static function readonly($value) {
      return $value;
    }

  // wholesaler shipping/payment modules Begin
    public static function show_modules($text) {
      return nl2br(implode("\n", explode(';', $text)));
    }

    public static function edit_modules($values, $key) {

      $file_extension = substr(Request::get_page(), strrpos(Request::get_page(), '.'));
      $files_array = [];

      if (strpos($key,'PAYMENT') !== false) {
        $module = 'payment';
        $installed_values = explode(';', MODULE_PAYMENT_INSTALLED);
      } elseif (strpos($key,'SHIPPING') !== false) {
        $module = 'shipping';
        $installed_values = explode(';', MODULE_SHIPPING_INSTALLED);
      } else{
        $module = '';
      }

      if ($dir = @dir(DIR_FS_CATALOG . 'includes/modules/' . $module . '/')) {
        while ($file = $dir->read()) {
          if (!is_dir(DIR_FS_CATALOG . 'includes/modules/' . $module . '/' . $file)) {
            if (substr($file, strrpos($file, '.')) == $file_extension) {
              $files_array[] = $file;
            }
          }
        }
        sort($files_array);
        $dir->close();
      }

      $values_array = explode(';', $values);

      $output = '';
      foreach ($files_array as $file) {
        if ( in_array($file, $installed_values ) ) {
          if ( in_array($file, $values_array) ) {
            $output .= new Tickable($key . 'st_wholesale_module[]', ['value' => $file, 'checked' => 'checked'], 'checkbox') . '&nbsp;' . Text::output($file) . '<br />';
          } else {
            $output .= new Tickable($key . 'st_wholesale_module[]', ['value' => $file], 'checkbox') . '&nbsp;' . Text::output($file) . '<br />';
          }
        }
      }

      if (!empty($output)) {
        $output = '<br />' . substr($output, 0, -6);
      }

      $output .= new Input('configuration[' . $key . ']', ['id' => $key . 'htrn_wholesale_modules"'], 'hidden');

      $output .= '<script>
                  function ' . $key . 'htrn_wholesale_update_cfg_value() {
                    var ' . $key . 'htrn_wholesale_selected_modules = \'\';

                    if ($(\'input[name="' . $key . 'st_wholesale_module[]"]\').length > 0) {
                      $(\'input[name="' . $key . 'st_wholesale_module[]"]:checked\').each(function() {
                        ' . $key . 'htrn_wholesale_selected_modules += $(this).attr(\'value\') + \';\';
                      });

                      if (' . $key . 'htrn_wholesale_selected_modules.length > 0) {
                        ' . $key . 'htrn_wholesale_selected_modules = ' . $key . 'htrn_wholesale_selected_modules.substring(0, ' . $key . 'htrn_wholesale_selected_modules.length - 1);
                      }
                    }

                    $(\'#' . $key . 'htrn_wholesale_modules\').val(' . $key . 'htrn_wholesale_selected_modules);
                  }

                  $(function() {
                    ' . $key . 'htrn_wholesale_update_cfg_value();

                    if ($(\'input[name="' . $key . 'st_wholesale_module[]"]\').length > 0) {
                      $(\'input[name="' . $key . 'st_wholesale_module[]"]\').change(function() {
                        ' . $key . 'htrn_wholesale_update_cfg_value();
                      });
                    }
                  });
                  </script>';

      return $output;
    }

  }
