<?php
/*
* $Id: product.php
* $Loc: /includes/system/override/wholesale/
*
* Name: WholesaleLite
* Version: 4.7.9
* Release Date: 10/19/2024
* Author: Rainer Schmied
* 	 phoenixcartaddonsaddons.com / raiwa@phoenixcartaddons.com
*
* License: Released under the GNU General Public License
*
* Comments: Author: [Rainer Schmied @raiwa]
* Author URI: [www.phoenixcartaddons.com]
* 
* CE Phoenix, E-Commerce made Easy
* https://phoenixcart.org
* 
* Copyright (c) 2021 Phoenix Cart
* 
* 
*/

  class Product extends product_builder {

    protected $_data = [];

    public function __construct($data = ['status' => 0]) {
      parent::__construct();

      foreach ($data as $key => $value) {
        $trimmed_key = Text::ltrim_once($key, 'products_');

        $this->_data[isset($data[$trimmed_key]) ? $key : $trimmed_key] = $value;
      }

//  wholesale 4.7.0 Lite wholesale price
      if ( isset($_SESSION['customer_id']) && isset($_SESSION['wholesale_group']) && $_SESSION['wholesale_group'] > '0' ) {
        $this->_data['wholesale'] = 1;
        $this->_data['wholesale_prefix'] = constant('MODULE_STORE_WHOLESALE_OPT_PRICE_SHORT_' . strtoupper($_SESSION['language'])) . ' ';
      } else {
        $this->_data['wholesale'] = 0;
        $this->_data['wholesale_prefix'] = '';
      }

      if (!isset($this->_data['final_price']) && isset($this->_data['base_price'])) {
        if ($this->_data['wholesale'] == 1) {
          $this->_data['final_price'] = $this->wholesale_price();
        } else {
          $this->_data['final_price'] = $this->_data['base_price'];
        }
      }

      if (isset($this->_data['id']) && !isset($this->_data['link'])) {
        $this->_data['link'] = static::build_link((int)$this->_data['id']);
      }
    }

    public function can($key) {
      return $this->has($key) || parent::can($key);
    }

    public function has($key) {
      return isset($this->_data[$key]) || array_key_exists($this->_data, $key);
    }

    public function get($key) {
      if (!isset($this->_data[$key])) {
        if (parent::can($key)) {
          call_user_func(static::$capabilities[$key], $this);
        } else {
          return null;
        }
      }

      return $this->_data[$key];
    }

    public function set($key, $value) {
      $this->_data[$key] = $value;
    }

    public function get_data() {
      return $this->_data;
    }

    public function hype_price($show_special_price = true) {
//  wholesale 4.7.0 Lite wholesale price
      if ($show_special_price && ($this->get('is_special') == 1)) {
        return sprintf(
          IS_PRODUCT_SHOW_PRICE_SPECIAL,
          $this->format('price'),
          $this->_data['wholesale_prefix'] . $this->format());
      }

      return sprintf(IS_PRODUCT_SHOW_PRICE, $this->_data['wholesale_prefix'] . $this->format());
    }

    public function format($price = 'final_price', $quantity = 1) {



      return $GLOBALS['currencies']->display_price($this->get($price), $this->get('tax_rate'), $quantity);
    }

    public function format_raw($price = 'final_price', $quantity = 1) {
      return $GLOBALS['currencies']->display_raw($this->get($price), $this->get('tax_rate'), $quantity);
    }

    public function increment_view_count() {
      $GLOBALS['db']->query("UPDATE products_description SET products_viewed = products_viewed+1 WHERE products_id = " . (int)$this->get('id') . " AND language_id = " . (int)$_SESSION['languages_id']);
    }

    public function find_path() {
      return (($categories = $this->get('categories')) && isset($categories[0]))
           ? Guarantor::ensure_global('category_tree')->find_path($categories[0])
           : '';
    }

    public function lacks_stock($quantity = null) {
      return $this->get('in_stock') < ($quantity ?? $this->get('quantity'));
    }

//  wholesale 4.7.0 Lite wholesale price
    public function wholesale_price($price = 'final_price', $quantity = 1) {
      if ( $this->_data['ws_price'] > 0 ) { // apply individual wholesale price
        $products_ws_price = $this->_data['ws_price'];
      } else if ( MODULE_STORE_WHOLESALE_GLOBAL_DISCOUNT > 0 ) { // apply global wholesale price discount
        $products_ws_price = $this->_data['price'] - ($this->_data['price'] * MODULE_STORE_WHOLESALE_GLOBAL_DISCOUNT/100);
      } else { // apply retail price
        $products_ws_price = $this->_data['price'];
      }
      if ( MODULE_STORE_WHOLESALE_SPECIAL_PRICE == 'True' && $this->_data['is_special'] == 1 && ($this->_data['specials_new_products_price'] < $products_ws_price)) { // apply special price as wholesale price
        $products_ws_price = $this->_data['specials_new_products_price'];
      }
      if (MODULE_STORE_WHOLESALE_TAX_EXEMPT == 'True') { // exempt wholesale customers from tax
        $this->_data['tax_class_id'] = 0;
      }

      return $products_ws_price;
    }

//  wholesale 4.7.0 Lite wholesale attribute price
    public static function load_attributes($product, $language_id = null) {
//  wholesale 4.7.0 Lite liberalize pa.*
      $attributes_query = $GLOBALS['db']->query(sprintf(<<<'EOSQL'
SELECT po.products_options_name, pov.products_options_values_name,
   pa.*,
   pad.products_attributes_filename, pad.products_attributes_maxdays, pad.products_attributes_maxcount
 FROM products_options po
  INNER JOIN products_attributes pa ON po.products_options_id = pa.options_id
  LEFT JOIN products_options_values pov ON pa.options_values_id = pov.products_options_values_id AND po.language_id = pov.language_id
  LEFT JOIN products_attributes_download pad ON pa.products_attributes_id = pad.products_attributes_id
 WHERE po.language_id = %d AND pa.products_id = %d
 ORDER BY po.sort_order, po.products_options_name, pov.sort_order, pov.products_options_values_name
EOSQL
      , (int)($language_id ?? $_SESSION['languages_id']), (int)$product->get('id')));

      $attributes = [];
      while ($attribute = $attributes_query->fetch_assoc()) {
        if (!isset($attributes[$attribute['options_id']])) {
          $attributes[$attribute['options_id']] = [
            'name' => $attribute['products_options_name'],
            'values' => [],
          ];
        }

//  wholesale 4.7.0 Lite define wholesale attributes price
        $values_price = $attribute['options_values_price'];
        if ( !empty($_SESSION['customer_id']) && defined('MODULE_STORE_WHOLESALE_STATUS') && MODULE_STORE_WHOLESALE_STATUS == 'True' && isset($_SESSION['wholesale_group']) && $_SESSION['wholesale_group'] > 0) { // wholesale attribute price
          if ( $attribute['options_values_ws_price'] != '0') { // apply individual wholesale attribute price
            $values_price = $attribute['options_values_ws_price'];
          } else if (MODULE_STORE_WHOLESALE_GLOBAL_DISCOUNT > '0') { // apply global wholesale price discount
            if ($attribute['price_prefix'] == '+') {
              $values_price = $attribute['options_values_price'] - ($attribute['options_values_price'] * MODULE_STORE_WHOLESALE_GLOBAL_DISCOUNT/100);
            } else {
              $values_price = $attribute['options_values_price'] + ($attribute['options_values_price'] * MODULE_STORE_WHOLESALE_GLOBAL_DISCOUNT/100);
            }
          }
        }

        $attributes[$attribute['options_id']]['values'][$attribute['options_values_id']] = [
          'name' => $attribute['products_options_values_name'],
          'prefix' => $attribute['price_prefix'],
          'price' => $values_price, // wholesale 4.5.0 Lite use wholesale attributes price
          'filename' => $attribute['products_attributes_filename'],
          'maxdays' => $attribute['products_attributes_maxdays'],
          'maxcount' => $attribute['products_attributes_maxcount'],
        ];
      }

      $product->set('has_attributes', (count($attributes) > 0) ? '1' : '0');
      $product->set('attributes', $attributes);
      return $attributes;
    }

  }
